@@ -41,6 +41,8 @@ parser.add_argument('--dpi', '-d', type=int,
                     help='the resolution of the output file')
 parser.add_argument('--output_folder', '-of', type=str, default=None,
                     help='the folder the graphs should be saved to')
+parser.add_argument('--skewIT', '-sk', argparse.SUPPRESS,
+                    help='The skewIT algorithm will be used for the graph. Use -sk true to activate this feature.')
 
 args = parser.parse_args()
 
@@ -54,13 +56,16 @@ for file in inputfiles:
 a = 0
 variable_list = []
 results_list = []
+skewi = False
+if 'SkewIT' in args:
+    skewi = True
 for sequence in sequence_list:
     variable_list.append('genskew' + str(a))
     results_list.append('result' + str(a))
     variable_list[a] = gs.Object(sequence, args.nuc_1, args.nuc_2, args.stepsize, args.windowsize)
     results_list[a] = gs.Object.gen_results(variable_list[a])
     print(str(a + 1) + " out of " + str(len(sequence_list)) + " graphs calculated...")
-    gs.plot_sequence(results_list[a], inputfiles[a], args.output_folder, args.out_file_type, args.dpi)
+    gs.plot_sequence(results_list[a], inputfiles[a], args.output_folder, args.out_file_type, args.dpi, skewi)
     print(str(a + 1) + " out of " + str(len(sequence_list)) + " graphs saved...")
     a = a + 1
 print('Done!')
